diff --git a/dist/changes-5.0.0 b/dist/changes-5.0.0
index f8a553a0bc..d3ea3fbcb3 100644
--- a/dist/changes-5.0.0
+++ b/dist/changes-5.0.0
@@ -423,6 +423,14 @@ QtNetwork
* The openssl network backend now reads the ssl configuration file allowing
the use of openssl engines.
+QtDBus
+------
+* QtDBus now generates property annotations for the Qt type names
+ in the org.qtproject.QtDBus namespace. When parsing such annotations
+ both the old and new namespaces are accepted.
+
+* QtDBus error codes have been updated to be on the org.qtproject.QtDBus.Error
+ namespace.
QtOpenGL
--------
diff --git a/src/dbus/qdbusinternalfilters.cpp b/src/dbus/qdbusinternalfilters.cpp
index de1191afea..28d43c8c89 100644
--- a/src/dbus/qdbusinternalfilters.cpp
+++ b/src/dbus/qdbusinternalfilters.cpp
@@ -88,7 +88,7 @@ static const char propertiesInterfaceXml[] =
" \n"
" \n"
" \n"
- " \n"
+ " \n"
" \n"
" \n";
diff --git a/src/dbus/qdbusmetaobject.cpp b/src/dbus/qdbusmetaobject.cpp
index a6e5f96eca..4fbf67a8b2 100644
--- a/src/dbus/qdbusmetaobject.cpp
+++ b/src/dbus/qdbusmetaobject.cpp
@@ -165,7 +165,7 @@ QDBusMetaObjectGenerator::findType(const QByteArray &signature,
if (type == QVariant::Invalid && !qt_dbus_metaobject_skip_annotations) {
// it's not a type normally handled by our meta type system
// it must contain an annotation
- QString annotationName = QString::fromLatin1("com.trolltech.QtDBus.QtTypeName");
+ QString annotationName = QString::fromLatin1("org.qtproject.QtDBus.QtTypeName");
if (id >= 0)
annotationName += QString::fromLatin1(".%1%2")
.arg(QLatin1String(direction))
@@ -175,6 +175,16 @@ QDBusMetaObjectGenerator::findType(const QByteArray &signature,
QByteArray typeName = annotations.value(annotationName).toLatin1();
// verify that it's a valid one
+ if (typeName.isEmpty()) {
+ // try the old annotation from Qt 4
+ annotationName = QString::fromLatin1("com.trolltech.QtDBus.QtTypeName");
+ if (id >= 0)
+ annotationName += QString::fromLatin1(".%1%2")
+ .arg(QLatin1String(direction))
+ .arg(id);
+ typeName = annotations.value(annotationName).toLatin1();
+ }
+
if (!typeName.isEmpty()) {
// type name found
type = QMetaType::type(typeName);
diff --git a/src/dbus/qdbusmisc.cpp b/src/dbus/qdbusmisc.cpp
index 30f2adc8b3..d92349b35c 100644
--- a/src/dbus/qdbusmisc.cpp
+++ b/src/dbus/qdbusmisc.cpp
@@ -86,11 +86,11 @@ QString qDBusInterfaceFromMetaObject(const QMetaObject *mo)
interface.replace(QLatin1String("::"), QLatin1String("."));
if (interface.startsWith(QLatin1String("QDBus"))) {
- interface.prepend(QLatin1String("com.trolltech.QtDBus."));
+ interface.prepend(QLatin1String("org.qtproject.QtDBus."));
} else if (interface.startsWith(QLatin1Char('Q')) &&
interface.length() >= 2 && interface.at(1).isUpper()) {
// assume it's Qt
- interface.prepend(QLatin1String("com.trolltech.Qt."));
+ interface.prepend(QLatin1String("org.qtproject.Qt."));
} else if (!QCoreApplication::instance()||
QCoreApplication::instance()->applicationName().isEmpty()) {
interface.prepend(QLatin1String("local."));
diff --git a/src/dbus/qdbusvirtualobject.cpp b/src/dbus/qdbusvirtualobject.cpp
index 7325bc1f58..a56a60f334 100644
--- a/src/dbus/qdbusvirtualobject.cpp
+++ b/src/dbus/qdbusvirtualobject.cpp
@@ -85,7 +85,7 @@ QT_END_NAMESPACE
virtual object. It must return xml of the form:
\code
-
+
\endcode
diff --git a/src/dbus/qdbusxmlgenerator.cpp b/src/dbus/qdbusxmlgenerator.cpp
index d97258d514..4ad8113cd0 100644
--- a/src/dbus/qdbusxmlgenerator.cpp
+++ b/src/dbus/qdbusxmlgenerator.cpp
@@ -115,7 +115,7 @@ static QString generateInterfaceXml(const QMetaObject *mo, int flags, int method
if (QDBusMetaType::signatureToType(signature) == QVariant::Invalid) {
const char *typeName = QVariant::typeToName(QVariant::Type(typeId));
- retval += QString::fromLatin1(">\n \n \n")
+ retval += QString::fromLatin1(">\n \n \n")
.arg(typeNameToXml(typeName));
} else {
retval += QLatin1String("/>\n");
@@ -157,7 +157,7 @@ static QString generateInterfaceXml(const QMetaObject *mo, int flags, int method
// do we need to describe this argument?
if (QDBusMetaType::signatureToType(typeName) == QVariant::Invalid)
- xml += QString::fromLatin1(" \n")
+ xml += QString::fromLatin1(" \n")
.arg(typeNameToXml(QVariant::typeToName(QVariant::Type(typeId))));
} else
continue;
@@ -201,7 +201,7 @@ static QString generateInterfaceXml(const QMetaObject *mo, int flags, int method
// do we need to describe this argument?
if (QDBusMetaType::signatureToType(signature) == QVariant::Invalid) {
const char *typeName = QVariant::typeToName( QVariant::Type(types.at(j)) );
- xml += QString::fromLatin1(" \n")
+ xml += QString::fromLatin1(" \n")
.arg(isOutput ? QLatin1String("Out") : QLatin1String("In"))
.arg(isOutput && !isSignal ? j - inputCount : j - 1)
.arg(typeNameToXml(typeName));
@@ -264,11 +264,11 @@ QString qDBusGenerateMetaObjectXml(QString interface, const QMetaObject *mo, con
interface.replace(QLatin1String("::"), QLatin1String("."));
if (interface.startsWith(QLatin1String("QDBus"))) {
- interface.prepend(QLatin1String("com.trolltech.QtDBus."));
+ interface.prepend(QLatin1String("org.qtproject.QtDBus."));
} else if (interface.startsWith(QLatin1Char('Q')) &&
interface.length() >= 2 && interface.at(1).isUpper()) {
// assume it's Qt
- interface.prepend(QLatin1String("com.trolltech.Qt."));
+ interface.prepend(QLatin1String("org.qtproject.Qt."));
} else if (!QCoreApplication::instance()||
QCoreApplication::instance()->applicationName().isEmpty()) {
interface.prepend(QLatin1String("local."));
diff --git a/tests/auto/dbus/qdbusabstractadaptor/qmyserver/qmyserver.cpp b/tests/auto/dbus/qdbusabstractadaptor/qmyserver/qmyserver.cpp
index d5d5f2c431..39e6633bfc 100644
--- a/tests/auto/dbus/qdbusabstractadaptor/qmyserver/qmyserver.cpp
+++ b/tests/auto/dbus/qdbusabstractadaptor/qmyserver/qmyserver.cpp
@@ -43,8 +43,8 @@
#include "../myobject.h"
-static const char serviceName[] = "com.trolltech.autotests.qmyserver";
-static const char objectPath[] = "/com/trolltech/qmyserver";
+static const char serviceName[] = "org.qtproject.autotests.qmyserver";
+static const char objectPath[] = "/org/qtproject/qmyserver";
//static const char *interfaceName = serviceName;
const char *slotSpy;
@@ -55,7 +55,7 @@ Q_DECLARE_METATYPE(QDBusConnection::RegisterOptions)
class MyServer : public QDBusServer
{
Q_OBJECT
- Q_CLASSINFO("D-Bus Interface", "com.trolltech.autotests.qmyserver")
+ Q_CLASSINFO("D-Bus Interface", "org.qtproject.autotests.qmyserver")
public:
MyServer(QString addr = "unix:tmpdir=/tmp", QObject* parent = 0)
diff --git a/tests/auto/dbus/qdbusabstractadaptor/tst_qdbusabstractadaptor.cpp b/tests/auto/dbus/qdbusabstractadaptor/tst_qdbusabstractadaptor.cpp
index c14d77eec3..30571fadd6 100644
--- a/tests/auto/dbus/qdbusabstractadaptor/tst_qdbusabstractadaptor.cpp
+++ b/tests/auto/dbus/qdbusabstractadaptor/tst_qdbusabstractadaptor.cpp
@@ -48,8 +48,8 @@
#include "../qdbusmarshall/common.h"
#include "myobject.h"
-static const char serviceName[] = "com.trolltech.autotests.qmyserver";
-static const char objectPath[] = "/com/trolltech/qmyserver";
+static const char serviceName[] = "org.qtproject.autotests.qmyserver";
+static const char objectPath[] = "/org/qtproject/qmyserver";
static const char *interfaceName = serviceName;
const char *slotSpy;
@@ -644,7 +644,7 @@ void tst_QDBusAbstractAdaptor::signalEmissions()
QDBusConnection con = QDBusConnection::sessionBus();
QVERIFY(con.isConnected());
- con.registerService("com.trolltech.tst_QDBusAbstractAdaptor");
+ con.registerService("org.qtproject.tst_QDBusAbstractAdaptor");
MyObject obj(3);
con.registerObject("/", &obj, QDBusConnection::ExportAdaptors
diff --git a/tests/auto/dbus/qdbusabstractinterface/interface.h b/tests/auto/dbus/qdbusabstractinterface/interface.h
index 2bd99fa11a..94addb7355 100644
--- a/tests/auto/dbus/qdbusabstractinterface/interface.h
+++ b/tests/auto/dbus/qdbusabstractinterface/interface.h
@@ -78,7 +78,7 @@ Q_DECLARE_METATYPE(UnregisteredType)
class Interface: public QObject
{
Q_OBJECT
- Q_CLASSINFO("D-Bus Interface", "com.trolltech.QtDBus.Pinger")
+ Q_CLASSINFO("D-Bus Interface", "org.qtproject.QtDBus.Pinger")
Q_PROPERTY(QString stringProp READ stringProp WRITE setStringProp SCRIPTABLE true)
Q_PROPERTY(QDBusVariant variantProp READ variantProp WRITE setVariantProp SCRIPTABLE true)
Q_PROPERTY(RegisteredType complexProp READ complexProp WRITE setComplexProp SCRIPTABLE true)
diff --git a/tests/auto/dbus/qdbusabstractinterface/com.trolltech.QtDBus.Pinger.xml b/tests/auto/dbus/qdbusabstractinterface/org.qtproject.QtDBus.Pinger.xml
similarity index 81%
rename from tests/auto/dbus/qdbusabstractinterface/com.trolltech.QtDBus.Pinger.xml
rename to tests/auto/dbus/qdbusabstractinterface/org.qtproject.QtDBus.Pinger.xml
index d945ec9b43..845e7be5b4 100644
--- a/tests/auto/dbus/qdbusabstractinterface/com.trolltech.QtDBus.Pinger.xml
+++ b/tests/auto/dbus/qdbusabstractinterface/org.qtproject.QtDBus.Pinger.xml
@@ -1,10 +1,10 @@
-
+
-
+
@@ -12,7 +12,7 @@
-
+
@@ -24,7 +24,7 @@
-
+
diff --git a/tests/auto/dbus/qdbusabstractinterface/pinger.cpp b/tests/auto/dbus/qdbusabstractinterface/pinger.cpp
index 93d4732f74..a931f41d6f 100644
--- a/tests/auto/dbus/qdbusabstractinterface/pinger.cpp
+++ b/tests/auto/dbus/qdbusabstractinterface/pinger.cpp
@@ -41,7 +41,7 @@
/*
* This file was generated by qdbusxml2cpp version 0.7
- * Command line was: qdbusxml2cpp -i interface.h -p pinger com.trolltech.QtDBus.Pinger.xml
+ * Command line was: qdbusxml2cpp -i interface.h -p pinger org.qtproject.QtDBus.Pinger.xml
*
* qdbusxml2cpp is Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
*
diff --git a/tests/auto/dbus/qdbusabstractinterface/qdbusabstractinterface.pro b/tests/auto/dbus/qdbusabstractinterface/qdbusabstractinterface.pro
index 9d8d542b88..623b07fcbd 100644
--- a/tests/auto/dbus/qdbusabstractinterface/qdbusabstractinterface.pro
+++ b/tests/auto/dbus/qdbusabstractinterface/qdbusabstractinterface.pro
@@ -3,4 +3,4 @@ TARGET = tst_qdbusabstractinterface
TEMPLATE = subdirs
CONFIG += ordered
SUBDIRS = qpinger test
-OTHER_FILES += com.trolltech.QtDBus.Pinger.xml
+OTHER_FILES += org.qtproject.QtDBus.Pinger.xml
diff --git a/tests/auto/dbus/qdbusabstractinterface/qpinger/qpinger.cpp b/tests/auto/dbus/qdbusabstractinterface/qpinger/qpinger.cpp
index 87c6bad7fc..3ecc839a34 100644
--- a/tests/auto/dbus/qdbusabstractinterface/qpinger/qpinger.cpp
+++ b/tests/auto/dbus/qdbusabstractinterface/qpinger/qpinger.cpp
@@ -42,14 +42,14 @@
#include
#include "../interface.h"
-static const char serviceName[] = "com.trolltech.autotests.qpinger";
-static const char objectPath[] = "/com/trolltech/qpinger";
+static const char serviceName[] = "org.qtproject.autotests.qpinger";
+static const char objectPath[] = "/org/qtproject/qpinger";
//static const char *interfaceName = serviceName;
class PingerServer : public QDBusServer
{
Q_OBJECT
- Q_CLASSINFO("D-Bus Interface", "com.trolltech.autotests.qpinger")
+ Q_CLASSINFO("D-Bus Interface", "org.qtproject.autotests.qpinger")
public:
PingerServer(QString addr = "unix:tmpdir=/tmp", QObject* parent = 0)
: QDBusServer(addr, parent),
diff --git a/tests/auto/dbus/qdbusabstractinterface/tst_qdbusabstractinterface.cpp b/tests/auto/dbus/qdbusabstractinterface/tst_qdbusabstractinterface.cpp
index 7ac5cd3c6c..59ec2955e4 100644
--- a/tests/auto/dbus/qdbusabstractinterface/tst_qdbusabstractinterface.cpp
+++ b/tests/auto/dbus/qdbusabstractinterface/tst_qdbusabstractinterface.cpp
@@ -49,8 +49,8 @@
#include "interface.h"
#include "pinger.h"
-static const char serviceName[] = "com.trolltech.autotests.qpinger";
-static const char objectPath[] = "/com/trolltech/qpinger";
+static const char serviceName[] = "org.qtproject.autotests.qpinger";
+static const char objectPath[] = "/org/qtproject/qpinger";
static const char *interfaceName = serviceName;
typedef QSharedPointer Pinger;
@@ -452,9 +452,9 @@ void tst_QDBusAbstractInterface::makeAsyncMultiOutCallPeer()
QCoreApplication::instance()->processEvents();
}
-static const char server_serviceName[] = "com.trolltech.autotests.dbusserver";
-static const char server_objectPath[] = "/com/trolltech/server";
-static const char server_interfaceName[] = "com.trolltech.QtDBus.Pinger";
+static const char server_serviceName[] = "org.qtproject.autotests.dbusserver";
+static const char server_objectPath[] = "/org/qtproject/server";
+static const char server_interfaceName[] = "org.qtproject.QtDBus.Pinger";
class DBusServerThread : public QThread
{
@@ -975,7 +975,7 @@ void tst_QDBusAbstractInterface::getComplexSignalPeer()
void tst_QDBusAbstractInterface::followSignal()
{
- const QString serviceToFollow = "com.trolltech.tst_qdbusabstractinterface.FollowMe";
+ const QString serviceToFollow = "org.qtproject.tst_qdbusabstractinterface.FollowMe";
Pinger p = getPinger(serviceToFollow);
QVERIFY2(p, "Not connected to D-Bus");
diff --git a/tests/auto/dbus/qdbusconnection/tst_qdbusconnection.cpp b/tests/auto/dbus/qdbusconnection/tst_qdbusconnection.cpp
index 65b68b7f34..f99220ea1a 100644
--- a/tests/auto/dbus/qdbusconnection/tst_qdbusconnection.cpp
+++ b/tests/auto/dbus/qdbusconnection/tst_qdbusconnection.cpp
@@ -118,7 +118,7 @@ private slots:
void callVirtualObjectLocal();
public:
- QString serviceName() const { return "com.trolltech.Qt.Autotests.QDBusConnection"; }
+ QString serviceName() const { return "org.qtproject.Qt.Autotests.QDBusConnection"; }
bool callMethod(const QDBusConnection &conn, const QString &path);
bool callMethodPeer(const QDBusConnection &conn, const QString &path);
};
@@ -970,7 +970,7 @@ void tst_QDBusConnection::slotsWithLessParameters()
{
QDBusConnection con = QDBusConnection::sessionBus();
- QDBusMessage signal = QDBusMessage::createSignal("/", "com.trolltech.TestCase",
+ QDBusMessage signal = QDBusMessage::createSignal("/", "org.qtproject.TestCase",
"oneSignal");
signal << "one parameter";
@@ -1051,7 +1051,7 @@ void tst_QDBusConnection::serviceRegistrationRaceCondition()
// connect to the signal:
RaceConditionSignalWaiter recv;
- session.connect(serviceName, "/", "com.trolltech.TestCase", "oneSignal", &recv, SLOT(countUp()));
+ session.connect(serviceName, "/", "org.qtproject.TestCase", "oneSignal", &recv, SLOT(countUp()));
// create a secondary connection and register a name
QDBusConnection connection = QDBusConnection::connectToBus(QDBusConnection::SessionBus, connectionName);
@@ -1060,7 +1060,7 @@ void tst_QDBusConnection::serviceRegistrationRaceCondition()
QVERIFY(connection.registerService(serviceName));
// send a signal
- QDBusMessage msg = QDBusMessage::createSignal("/", "com.trolltech.TestCase", "oneSignal");
+ QDBusMessage msg = QDBusMessage::createSignal("/", "org.qtproject.TestCase", "oneSignal");
connection.send(msg);
// make a blocking call just to be sure that the buffer was flushed
diff --git a/tests/auto/dbus/qdbuscontext/tst_qdbuscontext.cpp b/tests/auto/dbus/qdbuscontext/tst_qdbuscontext.cpp
index bc06f8e377..3ec9e636a8 100644
--- a/tests/auto/dbus/qdbuscontext/tst_qdbuscontext.cpp
+++ b/tests/auto/dbus/qdbuscontext/tst_qdbuscontext.cpp
@@ -41,13 +41,13 @@
#include
#include
-const char errorName[] = "com.trolltech.tst_QDBusContext.Error";
+const char errorName[] = "org.qtproject.tst_QDBusContext.Error";
const char errorMsg[] = "A generic error";
class TestObject: public QObject, protected QDBusContext
{
Q_OBJECT
- Q_CLASSINFO("D-Bus Interface", "com.trolltech.tst_QDBusContext.TestObject")
+ Q_CLASSINFO("D-Bus Interface", "org.qtproject.tst_QDBusContext.TestObject")
public:
inline TestObject(QObject *parent) : QObject(parent) { }
public Q_SLOTS:
diff --git a/tests/auto/dbus/qdbusinterface/myobject.h b/tests/auto/dbus/qdbusinterface/myobject.h
index 94e7b3d4c5..12c8da6ef6 100644
--- a/tests/auto/dbus/qdbusinterface/myobject.h
+++ b/tests/auto/dbus/qdbusinterface/myobject.h
@@ -50,12 +50,12 @@ Q_DECLARE_METATYPE(QVariantList)
class MyObject: public QObject
{
Q_OBJECT
- Q_CLASSINFO("D-Bus Interface", "com.trolltech.QtDBus.MyObject")
+ Q_CLASSINFO("D-Bus Interface", "org.qtproject.QtDBus.MyObject")
Q_CLASSINFO("D-Bus Introspection", ""
-" \n"
+" \n"
" \n"
" \n"
-" \n"
+" \n"
" \n"
" \n"
" \n"
@@ -83,14 +83,14 @@ class MyObject: public QObject
" \n"
" \n"
" \n"
-" \n"
-" \n"
+" \n"
+" \n"
" \n"
" \n"
" \n"
" \n"
-" \n"
-" \n"
+" \n"
+" \n"
" \n"
" \n"
"")
diff --git a/tests/auto/dbus/qdbusinterface/qmyserver/qmyserver.cpp b/tests/auto/dbus/qdbusinterface/qmyserver/qmyserver.cpp
index 1815a6ef79..cb3cd1b27e 100644
--- a/tests/auto/dbus/qdbusinterface/qmyserver/qmyserver.cpp
+++ b/tests/auto/dbus/qdbusinterface/qmyserver/qmyserver.cpp
@@ -43,8 +43,8 @@
#include "../myobject.h"
-static const char serviceName[] = "com.trolltech.autotests.qmyserver";
-static const char objectPath[] = "/com/trolltech/qmyserver";
+static const char serviceName[] = "org.qtproject.autotests.qmyserver";
+static const char objectPath[] = "/org/qtproject/qmyserver";
//static const char *interfaceName = serviceName;
int MyObject::callCount = 0;
@@ -53,7 +53,7 @@ QVariantList MyObject::callArgs;
class MyServer : public QDBusServer
{
Q_OBJECT
- Q_CLASSINFO("D-Bus Interface", "com.trolltech.autotests.qmyserver")
+ Q_CLASSINFO("D-Bus Interface", "org.qtproject.autotests.qmyserver")
public:
MyServer(QString addr = "unix:tmpdir=/tmp", QObject* parent = 0)
diff --git a/tests/auto/dbus/qdbusinterface/tst_qdbusinterface.cpp b/tests/auto/dbus/qdbusinterface/tst_qdbusinterface.cpp
index c866c9d155..af2355aa5d 100644
--- a/tests/auto/dbus/qdbusinterface/tst_qdbusinterface.cpp
+++ b/tests/auto/dbus/qdbusinterface/tst_qdbusinterface.cpp
@@ -50,11 +50,11 @@
#include "../qdbusmarshall/common.h"
#include "myobject.h"
-#define TEST_INTERFACE_NAME "com.trolltech.QtDBus.MyObject"
+#define TEST_INTERFACE_NAME "org.qtproject.QtDBus.MyObject"
#define TEST_SIGNAL_NAME "somethingHappened"
-static const char serviceName[] = "com.trolltech.autotests.qmyserver";
-static const char objectPath[] = "/com/trolltech/qmyserver";
+static const char serviceName[] = "org.qtproject.autotests.qmyserver";
+static const char objectPath[] = "/org/qtproject/qmyserver";
static const char *interfaceName = serviceName;
int MyObject::callCount = 0;
@@ -63,9 +63,9 @@ QVariantList MyObject::callArgs;
class MyObjectUnknownType: public QObject
{
Q_OBJECT
- Q_CLASSINFO("D-Bus Interface", "com.trolltech.QtDBus.MyObject")
+ Q_CLASSINFO("D-Bus Interface", "org.qtproject.QtDBus.MyObject")
Q_CLASSINFO("D-Bus Introspection", ""
-" \n"
+" \n"
" \n"
" \n"
" \n"
@@ -381,7 +381,7 @@ void tst_QDBusInterface::introspectUnknownTypes()
MyObjectUnknownType obj;
con.registerObject("/unknownTypes", &obj, QDBusConnection::ExportAllContents);
QDBusInterface iface(QDBusConnection::sessionBus().baseService(), QLatin1String("/unknownTypes"),
- "com.trolltech.QtDBus.MyObjectUnknownTypes");
+ "org.qtproject.QtDBus.MyObjectUnknownTypes");
const QMetaObject *mo = iface.metaObject();
QVERIFY(mo->indexOfMethod("regularMethod()") != -1); // this is the control
@@ -414,7 +414,7 @@ public:
if (path == "/some/path/superNode")
return "zitroneneis";
if (path == "/some/path/superNode/foo")
- return " \n"
+ return " \n"
" \n"
" \n" ;
return QString();
@@ -460,7 +460,7 @@ void tst_QDBusInterface::introspectVirtualObject()
QDBusMessage message2 = QDBusMessage::createMethodCall(con.baseService(), path + "/foo", "org.freedesktop.DBus.Introspectable", "Introspect");
QDBusMessage reply2 = con.call(message2, QDBus::Block, 5000);
QVERIFY(reply2.arguments().at(0).toString().contains(
- QRegExp(".*"
+ QRegExp(".*"
".*\n"
".*.*
-static const char serviceName[] = "com.trolltech.autotests.qpong";
-static const char objectPath[] = "/com/trolltech/qpong";
+static const char serviceName[] = "org.qtproject.autotests.qpong";
+static const char objectPath[] = "/org/qtproject/qpong";
static const char *interfaceName = serviceName;
class tst_QDBusMarshall: public QObject
@@ -925,7 +925,7 @@ void tst_QDBusMarshall::sendCallErrors_data()
// this error comes from the bus server
QTest::newRow("empty-service") << "" << objectPath << interfaceName << "ping" << QVariantList()
<< "org.freedesktop.DBus.Error.UnknownMethod"
- << "Method \"ping\" with signature \"\" on interface \"com.trolltech.autotests.qpong\" doesn't exist\n" << (const char*)0;
+ << "Method \"ping\" with signature \"\" on interface \"org.qtproject.autotests.qpong\" doesn't exist\n" << (const char*)0;
QTest::newRow("invalid-service") << "this isn't valid" << objectPath << interfaceName << "ping" << QVariantList()
<< "org.qtproject.QtDBus.Error.InvalidService"
diff --git a/tests/auto/dbus/qdbusmetaobject/tst_qdbusmetaobject.cpp b/tests/auto/dbus/qdbusmetaobject/tst_qdbusmetaobject.cpp
index a523a66bdd..b459fdc1b1 100644
--- a/tests/auto/dbus/qdbusmetaobject/tst_qdbusmetaobject.cpp
+++ b/tests/auto/dbus/qdbusmetaobject/tst_qdbusmetaobject.cpp
@@ -297,7 +297,7 @@ signals:
};
const char TypesTest16_xml[] =
""
- "";
+ "";
class TypesTest17: public QObject
{
@@ -308,7 +308,7 @@ signals:
};
const char TypesTest17_xml[] =
""
- "";
+ "";
class TypesTest18: public QObject
{
@@ -319,7 +319,7 @@ signals:
};
const char TypesTest18_xml[] =
""
- "";
+ "";
class TypesTest19: public QObject
{
@@ -330,7 +330,7 @@ signals:
};
const char TypesTest19_xml[] =
""
- "";
+ "";
class TypesTest20: public QObject
{
@@ -340,9 +340,13 @@ signals:
void signal(QVariantMap);
};
const char TypesTest20_xml[] =
+ ""
+ "";
+const char TypesTest20_oldxml[] =
""
"";
+
void tst_QDBusMetaObject::types_data()
{
QTest::addColumn("metaobject");
@@ -368,6 +372,7 @@ void tst_QDBusMetaObject::types_data()
QTest::newRow("Struct4") << &TypesTest18::staticMetaObject << QString(TypesTest18_xml);
QTest::newRow("QVariantList") << &TypesTest19::staticMetaObject << QString(TypesTest19_xml);
QTest::newRow("QVariantMap") << &TypesTest20::staticMetaObject << QString(TypesTest20_xml);
+ QTest::newRow("QVariantMap-oldannotation") << &TypesTest20::staticMetaObject << QString(TypesTest20_oldxml);
}
void tst_QDBusMetaObject::types()
@@ -671,7 +676,7 @@ public:
};
const char PropertyTest4_xml[] =
""
- ""
+ ""
"";
class PropertyTest_b: public QObject
diff --git a/tests/auto/dbus/qdbuspendingcall/tst_qdbuspendingcall.cpp b/tests/auto/dbus/qdbuspendingcall/tst_qdbuspendingcall.cpp
index 60a8061ae4..eca352456f 100644
--- a/tests/auto/dbus/qdbuspendingcall/tst_qdbuspendingcall.cpp
+++ b/tests/auto/dbus/qdbuspendingcall/tst_qdbuspendingcall.cpp
@@ -46,12 +46,12 @@
#include
#include
-#define TEST_INTERFACE_NAME "com.trolltech.QtDBus.MyObject"
+#define TEST_INTERFACE_NAME "org.qtproject.QtDBus.MyObject"
class MyObject : public QDBusAbstractAdaptor
{
Q_OBJECT
- Q_CLASSINFO("D-Bus Interface", "com.trolltech.QtDBus.MyObject")
+ Q_CLASSINFO("D-Bus Interface", "org.qtproject.QtDBus.MyObject")
public:
MyObject(QObject* parent =0)
diff --git a/tests/auto/dbus/qdbuspendingreply/tst_qdbuspendingreply.cpp b/tests/auto/dbus/qdbuspendingreply/tst_qdbuspendingreply.cpp
index 865c9a86ff..6d5bdf7ba6 100644
--- a/tests/auto/dbus/qdbuspendingreply/tst_qdbuspendingreply.cpp
+++ b/tests/auto/dbus/qdbuspendingreply/tst_qdbuspendingreply.cpp
@@ -106,7 +106,7 @@ private slots:
class TypesInterface: public QDBusAbstractAdaptor
{
Q_OBJECT
- Q_CLASSINFO("D-Bus Interface", "com.trolltech.Qt.Autotests.TypesInterface")
+ Q_CLASSINFO("D-Bus Interface", "org.qtproject.Qt.Autotests.TypesInterface")
public:
TypesInterface(QObject *parent)
: QDBusAbstractAdaptor(parent)
@@ -241,7 +241,7 @@ tst_QDBusPendingReply::tst_QDBusPendingReply()
QDBusConnection::sessionBus().registerObject("/", this);
iface = new QDBusInterface(QDBusConnection::sessionBus().baseService(), "/",
- "com.trolltech.Qt.Autotests.TypesInterface",
+ "org.qtproject.Qt.Autotests.TypesInterface",
QDBusConnection::sessionBus(),
this);
}
diff --git a/tests/auto/dbus/qdbusreply/tst_qdbusreply.cpp b/tests/auto/dbus/qdbusreply/tst_qdbusreply.cpp
index b6026f215b..a5ccd24735 100644
--- a/tests/auto/dbus/qdbusreply/tst_qdbusreply.cpp
+++ b/tests/auto/dbus/qdbusreply/tst_qdbusreply.cpp
@@ -102,7 +102,7 @@ private slots:
class TypesInterface: public QDBusAbstractAdaptor
{
Q_OBJECT
- Q_CLASSINFO("D-Bus Interface", "com.trolltech.Qt.Autotests.TypesInterface")
+ Q_CLASSINFO("D-Bus Interface", "org.qtproject.Qt.Autotests.TypesInterface")
public:
TypesInterface(QObject *parent)
: QDBusAbstractAdaptor(parent)
@@ -226,7 +226,7 @@ tst_QDBusReply::tst_QDBusReply()
QDBusConnection::sessionBus().registerObject("/", this);
iface = new QDBusInterface(QDBusConnection::sessionBus().baseService(), "/",
- "com.trolltech.Qt.Autotests.TypesInterface",
+ "org.qtproject.Qt.Autotests.TypesInterface",
QDBusConnection::sessionBus(),
this);
}
diff --git a/tests/auto/dbus/qdbusabstractinterface/pinger.h b/tests/auto/dbus/qdbusabstractinterface/pinger.h
index eb05d7535a..7fc6e640fe 100644
--- a/tests/auto/dbus/qdbusabstractinterface/pinger.h
+++ b/tests/auto/dbus/qdbusabstractinterface/pinger.h
@@ -41,7 +41,7 @@
/*
* This file was generated by qdbusxml2cpp version 0.7
* Command line was: qdbusxml2cpp -i interface.h -p pinger com.trolltech.QtDBus.Pinger.xml
*
* qdbusxml2cpp is Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
*
@@ -63,14 +63,14 @@
#include "interface.h"
/*
* Proxy class for interface com.trolltech.QtDBus.Pinger
*/
class ComTrolltechQtDBusPingerInterface: public QDBusAbstractInterface
{
Q_OBJECT
public:
static inline const char *staticInterfaceName()
- { return "com.trolltech.QtDBus.Pinger"; }
+ { return "org.qtproject.QtDBus.Pinger"; }
public:
ComTrolltechQtDBusPingerInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = 0);
@@ -41,7 +41,7 @@
/*
* This file was generated by qdbusxml2cpp version 0.7
- * Command line was: qdbusxml2cpp -i interface.h -p pinger com.trolltech.QtDBus.Pinger.xml
+ * Command line was: qdbusxml2cpp -i interface.h -p pinger org.qtproject.QtDBus.Pinger.xml
*
* qdbusxml2cpp is Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
@@ -63,14 +63,14 @@
#include "interface.h"
/*
- * Proxy class for interface com.trolltech.QtDBus.Pinger
+ * Proxy class for interface org.qtproject.QtDBus.Pinger
*/
class ComTrolltechQtDBusPingerInterface: public QDBusAbstractInterface